@@ -1,5 +1,7 @@
 from __future__ import annotations
 
+from inspect import isclass
+from logging import getLogger
 from typing import TYPE_CHECKING, Iterable, Union, get_args, get_origin
 
 from hikari import CommandOption, OptionType
@@ -15,16 +17,19 @@ from crescent.commands.args import (
     Name,
 )
 from crescent.commands.options import OPTIONS_TYPE_MAP, get_channel_types
-from crescent.context import Context
+from crescent.context import BaseContext
 
 if TYPE_CHECKING:
-    from inspect import Parameter
     from typing import Any, Sequence, TypeVar
 
+    from sigparse import Parameter
+
     from crescent.typedefs import AutocompleteCallbackT
 
     T = TypeVar("T")
 
+_LOG = getLogger(__name__)
+
 __all__: Sequence[str] = ("gen_command_option", "get_autocomplete_func")
 
 NoneType = type(None)
@@ -61,12 +66,19 @@ def _get_origin_and_metadata(param: Parameter) -> tuple[Any, Iterable[Any]]:
     return origin, metadata
 
 
+def _any_issubclass(obj: Any, cls: type) -> bool:
+    if not isclass(obj):
+        return False
+    return issubclass(obj, cls)
+
+
 def gen_command_option(param: Parameter) -> CommandOption | None:
-    name = param.name
+    if not param.has_annotation:
+        return None
 
     origin, metadata = _get_origin_and_metadata(param)
 
-    if origin in {Context, param.empty}:
+    if _any_issubclass(origin, BaseContext):
         return None
 
     _type = OPTIONS_TYPE_MAP.get(origin)
@@ -82,7 +94,7 @@ def gen_command_option(param: Parameter) -> CommandOption | None:
             " `hikari.Role`, `hikari.User`, or `crescent.Mentionable`."
         )
 
-    name = _get_arg(Name, metadata) or name
+    name = _get_arg(Name, metadata) or param.name
     description = _get_arg(Description, metadata) or _get_arg(str, metadata) or "No Description"
     choices = _get_arg(Choices, metadata)
     channel_types = _channel_types or _get_arg(ChannelTypes, metadata)
@@ -90,7 +102,7 @@ def gen_command_option(param: Parameter) -> CommandOption | None:
     max_value = _get_arg(MaxValue, metadata)
     autocomplete = _get_arg(Autocomplete, metadata)
 
-    required = param.default is param.empty
+    required = not param.has_default
 
     return CommandOption(
         name=name,
